@@ -10,10 +10,12 @@ sub like($$) {
 }
 
 sub in($$) {
-    die 'Not ArrayRef'              unless 'ARRAY' eq ref $_[1];
+    my ($str, $list) = @_;
 
-    return 'Value not defined'      unless defined $_[0];
-    return 'Wrong value'            unless any {$_ && $_[0] eq $_} @{$_[1]};
+    die 'Not ArrayRef'              unless 'ARRAY' eq ref $list;
+
+    return 'Value not defined'      unless defined $str;
+    return 'Wrong value'            unless any {$_ && $str eq $_} @$list;
 
     return 0;
 }
